==> file-roller-2.26.1-i486-1gsb.tgz: install/doinst.sh <==
( cd usr/share/gnome/help/file-roller/bg/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/bg/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/bg/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/bg/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/bg/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/bg/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/el/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/el/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/el/figures ; rm -rf file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/el/figures ; ln -sf ../../C/figures/file-roller_leftarrow.png file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/el/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/el/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/el/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/el/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/es/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/es/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/es/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/es/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/es/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/es/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/fi/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/fi/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/fi/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/fi/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/fi/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/fi/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/fr/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/fr/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/fr/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/fr/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/fr/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/fr/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; rm -rf file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; ln -sf ../../C/figures/file-roller_main_window.png file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; rm -rf file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; ln -sf ../../C/figures/file-roller_leftarrow.png file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; rm -rf file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; ln -sf ../../C/figures/file-roller_main_window.png file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; rm -rf file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; ln -sf ../../C/figures/file-roller_leftarrow.png file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; rm -rf file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; ln -sf ../../C/figures/file-roller_main_window.png file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; rm -rf file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; ln -sf ../../C/figures/file-roller_leftarrow.png file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/sv/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/sv/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/sv/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/sv/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/sv/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/sv/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; rm -rf file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; ln -sf ../../C/figures/file-roller_main_window.png file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; rm -rf file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; ln -sf ../../C/figures/file-roller_leftarrow.png file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; rm -rf file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; ln -sf ../../C/figures/file-roller_main_window.png file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; rm -rf file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; ln -sf ../../C/figures/file-roller_leftarrow.png file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/file-roller.schemas >/dev/null 2>&1
fi
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-mime-database ]; then
  usr/bin/update-mime-database usr/share/mime 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

for i in gnome hicolor
do
    if [ -e usr/share/icons/$i/icon-theme.cache ]; then
        rm -f usr/share/icons/$i/icon-theme.cache
    fi
    usr/bin/gtk-update-icon-cache -f -q --ignore-theme-index usr/share/icons/$i
done

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi

==> file-roller-2.26.3-i486-1gsb.tgz: install/doinst.sh <==
( cd usr/share/gnome/help/file-roller/bg/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/bg/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/bg/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/bg/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/bg/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/bg/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/el/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/el/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/el/figures ; rm -rf file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/el/figures ; ln -sf ../../C/figures/file-roller_leftarrow.png file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/el/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/el/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/el/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/el/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/es/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/es/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/es/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/es/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/es/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/es/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/fi/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/fi/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/fi/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/fi/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/fi/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/fi/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/fr/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/fr/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/fr/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/fr/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/fr/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/fr/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; rm -rf file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; ln -sf ../../C/figures/file-roller_main_window.png file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; rm -rf file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; ln -sf ../../C/figures/file-roller_leftarrow.png file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/nl/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; rm -rf file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; ln -sf ../../C/figures/file-roller_main_window.png file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; rm -rf file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; ln -sf ../../C/figures/file-roller_leftarrow.png file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/oc/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; rm -rf file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; ln -sf ../../C/figures/file-roller_main_window.png file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; rm -rf file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; ln -sf ../../C/figures/file-roller_leftarrow.png file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/ru/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/sv/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/sv/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/sv/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/sv/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/sv/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/sv/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; rm -rf file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; ln -sf ../../C/figures/file-roller_main_window.png file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; rm -rf file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; ln -sf ../../C/figures/file-roller_leftarrow.png file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/vi/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; rm -rf file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; ln -sf ../../C/figures/file-roller_uparrow.png file-roller_uparrow.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; rm -rf file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; ln -sf ../../C/figures/file-roller_main_window.png file-roller_main_window.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; rm -rf file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; ln -sf ../../C/figures/file-roller_leftarrow.png file-roller_leftarrow.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; rm -rf file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; ln -sf ../../C/figures/file-roller_rightarrow.png file-roller_rightarrow.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; rm -rf file-roller_home.png )
( cd usr/share/gnome/help/file-roller/en_GB/figures ; ln -sf ../../C/figures/file-roller_home.png file-roller_home.png )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/file-roller.schemas >/dev/null 2>&1
fi
if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-mime-database ]; then
  usr/bin/update-mime-database usr/share/mime 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

for i in gnome hicolor
do
    if [ -e usr/share/icons/$i/icon-theme.cache ]; then
        rm -f usr/share/icons/$i/icon-theme.cache
    fi
    usr/bin/gtk-update-icon-cache -f -q --ignore-theme-index usr/share/icons/$i 1>/dev/null 2>/dev/null
done

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi
